summaryrefslogtreecommitdiffstats
path: root/knode/knprotocolclient.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'knode/knprotocolclient.cpp')
-rw-r--r--knode/knprotocolclient.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/knode/knprotocolclient.cpp b/knode/knprotocolclient.cpp
index 4831087c..4b9137a5 100644
--- a/knode/knprotocolclient.cpp
+++ b/knode/knprotocolclient.cpp
@@ -166,7 +166,7 @@ void KNProtocolClient::waitForWork()
if (isConnected()) // connection is ready
processJob();
}
- errorPrefix = TQString::null;
+ errorPrefix = TQString();
clearPipe();
}
@@ -218,7 +218,7 @@ bool KNProtocolClient::openConnection()
}
// sends QUIT-command and closes the socket
void KNProtocolClient::closeConnection()
{
fd_set fdsW;
@@ -235,7 +235,7 @@ void KNProtocolClient::closeConnection()
int ret = KSocks::self()->select(FD_SETSIZE, NULL, &fdsW, NULL, &tv);
if (ret > 0) { // we can write...
- TQCString cmd = "QUIT\r\n";
+ TQCString cmd = "TQUIT\r\n";
int todo = cmd.length();
KSocks::self()->write(tcpSocket,&cmd.data()[0],todo);
}
@@ -218,7 +218,7 @@ bool KNProtocolClient::openConnection()
}
-// sends QUIT-command and closes the socket
+// sends TQUIT-command and closes the socket
void KNProtocolClient::closeConnection()
{